#!/usr/bin/env python

import pylab
import matplotlib.image as mpimg
import numpy as np
import sys
import os

    
def to_luminance(arr):
    wR = 0.2126
    wG = 0.7152
    wB = 0.0722
    return arr[:,:,0]*wR + arr[:,:,1]*wG + arr[:,:,2]*wB


def compute_mse(file_groundtruth, file_image):   
    # load images
    groundtruth = mpimg.imread(file_groundtruth)
    image       = mpimg.imread(file_image)

    # convert to luminance images
    lum1 = to_luminance(groundtruth)
    lum2 = to_luminance(image)
    
    # compute mse
    difference = image-groundtruth
    mse  = (difference**2).mean()
    #msef = ((difference*256)**2).mean()

    return mse


numReferenceImages = 32
#modelNames         = ["Angel", "Bee", "Cruciform", "Drache", "Elefant", "Lucy", "Nofretete", "Santa", "Thai"]
modelNames         = ["Angel", "Cruciform", "Drache", "Elefant", "Nofretete", "Santa"]

print "Average MSE Table:"

print "Model \t\t & $128 \\times 128$ \t & $256 \\times 256$ \t & $512 \\times 512$ \\\\"
print "\\hline"
for modelName in modelNames:
    print modelName + " \t\t &",
    for res in [128, 256, 512]:        
        dirFullQuality = "image-series-full-quality/" + modelName + "/" + str(numReferenceImages) + "/"
        dirReduced     = "3Dthumbs-renderings/"       + modelName + "/tex" + str(res) + "/"
        mse = 0
        for i in range(0,numReferenceImages):
            imageFullQuality    = dirFullQuality + "view" + str(i) + ".png"
            imageReducedQuality = dirReduced     + "view" + str(i) + ".png"
            mse += compute_mse(imageFullQuality, imageReducedQuality)        
        print "%.2e" % (mse / numReferenceImages) + "\t",
        if res != 512:
            print "&",
    print "\\\\"


